import json
import requests
from datetime import datetime, timedelta


last_notification_time = None


def send_rate_limited_notification(event_id, camera, object_label, score, quiet_period=1):
    global last_notification_time

    now = datetime.now()
    if last_notification_time is None or now - last_notification_time >= timedelta(minutes=quiet_period):
        last_notification_time = now
        send_notification(event_id, camera, object_label, score, priority=3)


def send_notification(event_id, camera, object_label, score, priority=3):
    camera_location = ' '.join(word.capitalize() for word in camera.split('_'))

    response = requests.post('https://ntfy.homelab.net', json={
        'topic': 'frigate_notifications',
        'title': 'Frigate',
        'message': f'{object_label.capitalize()} at {camera_location} ({score:.0%})',
        'priority': priority,
        'click': f'https://frigate.homelab.net/cameras/{camera}',
        'icon': 'https://cdn.jsdelivr.net/gh/walkxcode/dashboard-icons/png/frigate.png',
        'attach': f'https://frigate.homelab.net/api/events/{event_id}/thumbnail.jpg?format=android',
        'actions': [
            {
                'action': 'http',
                'label': 'Disable (30m)',
                'url': 'https://www.google.com/',
                'method': 'GET',
                'clear': True
            }
        ]
    })

    response2 = requests.post('https://ntfy.homelab.net', json={
        'topic': 'frigate_notifications_dad',
        'title': 'Frigate',
        'message': f'{object_label.capitalize()} at {camera_location} ({score:.0%})',
        'priority': priority,
        'click': f'https://frigate.homelab.net/cameras/{camera}',
        'icon': 'https://cdn.jsdelivr.net/gh/walkxcode/dashboard-icons/png/frigate.png',
        'attach': f'https://frigate.homelab.net/api/events/{event_id}/thumbnail.jpg?format=android',
        'actions': [
            {
                'action': 'http',
                'label': 'DBL (30m)',
                'url': 'https://www.google.com/',
                'method': 'GET',
                'clear': True
            }
        ]
    })

    return response.status_code == 200 and response2.status_code == 200
